#!/bin/bash

for SCRIPT in /etc/acpi/suspend.d/*.sh; do
    if [ -x $SCRIPT ]; then
	. $SCRIPT
    fi
done